@@ -1,4 +1,5 @@
 # coding: utf-8
+# frozen_string_literal: true
 
 ################################################################################
 #
@@ -179,7 +180,7 @@ module PDF
       (1..self.page_count).map do |num|
         begin
           PDF::Reader::Page.new(@objects, num, :cache => @cache)
-        rescue InvalidPageError => ex
+        rescue InvalidPageError
           raise MalformedPDFError, "Missing data for page: #{num}"
         end
       end
@@ -300,4 +301,3 @@ require 'pdf/reader/token'
 require 'pdf/reader/xref'
 require 'pdf/reader/orientation_detector'
 require 'pdf/reader/page'
-require 'pdf/hash'
