@@ -1,4 +1,5 @@
 # coding: utf-8
+# frozen_string_literal: true
 
 require 'pdf/reader/transformation_matrix'
 
@@ -29,7 +30,15 @@ class PDF::Reader
         @xobject_stack = [page.xobjects]
         @cs_stack      = [page.color_spaces]
         @stack         = [DEFAULT_GRAPHICS_STATE.dup]
-        state[:ctm]    = identity_matrix
+        if page.rotate == 0
+          state[:ctm]  = identity_matrix
+        else
+          rotate_cos = Math.cos(page.rotate * (Math::PI/180.0)).round(2)
+          rotate_sin = Math.sin(page.rotate * (Math::PI/180.0)).round(2)
+          state[:ctm] = TransformationMatrix.new(rotate_cos, rotate_sin,
+                                                 rotate_sin * -1, rotate_cos,
+                                                 0, 0)
+        end
       end
 
       #####################################################
