@@ -1,4 +1,5 @@
 # coding: utf-8
+# frozen_string_literal: true
 
 class PDF::Reader
   module WidthCalculator
@@ -17,8 +18,7 @@ class PDF::Reader
 
       def glyph_width(code_point)
         return 0 if code_point.nil? || code_point < 0
-
-        glyph_width_from_font(code_point) || glyph_width_from_descriptor(code_point)
+        glyph_width_from_font(code_point) || glyph_width_from_descriptor(code_point) || 0
       end
 
       private
