@@ -70,6 +70,17 @@ describe PDF::Reader, "integration specs" do
     end
   end
 
+  context "PDF with a difference table (v2)" do
+    let(:filename) { pdf_spec_file("difference_table2") }
+
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eql("This PDF contains ligatures,for example in “ﬁle”and “ﬂoor”.")
+      end
+    end
+  end
+
   context "PDF with a content stream that has trailing whitespace" do
     let(:filename) { pdf_spec_file("content_stream_trailing_whitespace") }
 
@@ -805,8 +816,17 @@ describe PDF::Reader, "integration specs" do
     let(:filename) { pdf_spec_file("junk_prefix") }
 
     it "extracts text correctly" do
-      filename = pdf_spec_file("junk_prefix")
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eql("This PDF contains junk before the %-PDF marker")
+      end
+    end
+  end
 
+  context "PDF with a 1024 bytes of junk prefix" do
+    let(:filename) { pdf_spec_file("junk_prefix_1024") }
+
+    it "extracts text correctly" do
       PDF::Reader.open(filename) do |reader|
         page = reader.page(1)
         expect(page.text).to eql("This PDF contains junk before the %-PDF marker")
@@ -867,6 +887,28 @@ describe PDF::Reader, "integration specs" do
     end
   end
 
+  context "PDF that uses a type1 font that isn't embedded and isn't one of the 14 built-ins" do
+    let(:filename) { pdf_spec_file("type1-arial") }
+
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eq("This text uses a Type1 font that isn't embedded")
+      end
+    end
+  end
+
+  context "PDF that uses a TrueType font that isn't embedded and has no metrics" do
+    let(:filename) { pdf_spec_file("truetype-arial") }
+
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to start_with("This text uses a TrueType font that isn't embedded")
+      end
+    end
+  end
+
   context "PDF that uses a type3 bitmap font" do
     let(:filename) { pdf_spec_file("type3_font") }
 
@@ -901,6 +943,20 @@ describe PDF::Reader, "integration specs" do
     end
   end
 
+  context "PDF with a Type0 font and Encoding is a CMap called OneByteIdentityH" do
+    let(:filename) { pdf_spec_file("one-byte-identity") }
+
+    # I'm not 100% confident that we'rr correctly handling OneByteIdentityH files in a way
+    # that will always work. It works for the sample file I have though, so that's better than
+    # nothing
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eq("abc")
+      end
+    end
+  end
+
   context "PDF with rotated text" do
     let(:filename) { pdf_spec_file("rotated_text") }
 
@@ -970,6 +1026,17 @@ describe PDF::Reader, "integration specs" do
     end
   end
 
+  context "Scanned PDF with invisible text added by ClearScan" do
+    let(:filename) { pdf_spec_file("clearscan") }
+
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eq("This document was scanned and then OCRd with Adobe ClearScan")
+      end
+    end
+  end
+
   context "PDF with text that contains a control char" do
     let(:filename) { pdf_spec_file("times-with-control-character") }
 
@@ -1044,4 +1111,61 @@ describe PDF::Reader, "integration specs" do
       end
     end
   end
+
+  context "PDF with overlapping chars to achieve fake bold effect" do
+    let(:filename) { pdf_spec_file("overlapping-chars-xy-fake-bold") }
+    let(:text) {
+      "Some characters that overlap with different X and Y to achieve a fake bold effect"
+    }
+
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eq(text)
+      end
+    end
+  end
+
+  context "PDF with overlapping chars (same Y pos) to achieve fake bold effect" do
+    let(:filename) { pdf_spec_file("overlapping-chars-x-fake-bold") }
+    let(:text) {
+      "Some characters that overlap with different X to achieve a fake bold effect"
+    }
+
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eq(text)
+      end
+    end
+  end
+
+  context "PDF with 180 page rotation followed by matrix transformations to undo it" do
+    let(:filename) { pdf_spec_file("rotate-180") }
+    let(:text) {
+      "This text is rendered upside down\nand then the page is rotated"
+    }
+
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eq(text)
+      end
+    end
+  end
+
+  context "PDF with page rotation followed by matrix transformations to undo it" do
+    let(:filename) { pdf_spec_file("rotate-then-undo") }
+    let(:text) {
+      "This page uses matrix transformations to print text sideways, " +
+      "then has a Rotate key to fix it"
+    }
+
+    it "extracts text correctly" do
+      PDF::Reader.open(filename) do |reader|
+        page = reader.page(1)
+        expect(page.text).to eq(text)
+      end
+    end
+  end
 end
